KeymintSealedData

Struct KeymintSealedData 

pub struct KeymintSealedData {
    pub sealing_key_info: Vec<u8>,
    pub sealing_key_blob: Vec<u8>,
    pub sealed_keys: BTreeMap<String, Vec<u8>>,
    pub old_blob: Option<Vec<u8>>,
}
Bundles together a handle to a Keymint sealing key together with a list of keys sealed by the sealing key. The contents of this struct can be persistently stored, as it contains no plaintext secrets.

Fields

sealing_key_info: Vec<u8>sealing_key_blob: Vec<u8>sealed_keys: BTreeMap<String, Vec<u8>>old_blob: Option<Vec<u8>>

Implementations

Source

impl KeymintSealedData

pub async fn new() -> Result<Self, Error>

Generates a new hardware-backed sealing key based off of sealing_key_info and creates a new instance of KeymintSealedData which uses this sealing key.

Note that repeated calls to this will yield different sealing keys. The sealing key should be persisted if it needs to be reused.

pub async fn create_key(&mut self, label: &str) -> Result<Vec<u8>, Error>

Generates and seals a new key named label. Updates this struct to contain the sealed key (to be retrieved later by Self::unseal_key), and returns the unsealed key.

pub async fn unseal_key(&self, label: &str) -> Result<UnsealResult, Error>

Unseals a key previously created via Self::create_key. Returns either the unsealed key, or a UnsealResult::KeyRequiresUpgrade if the hardware determines the sealing protocol format is too old.

pub async fn upgrade_sealing_blob(&mut self) -> Result<(), Error>

Attempts to upgrade the hardware sealing blob for the current configuration. In the event of a successful upgrade, the previous active blob is moved to old_blob for cleanup.